@@ -12,6 +12,8 @@ pub enum Error {
     BlockNotFound(u64),
     #[error("no endpoints provided")]
     EmptyEndpoints,
+    #[error("invalid path")]
+    InvalidPath,
     #[error("invalid block range")]
     InvalidRange,
     #[error("invalid timestamp")]
@@ -24,8 +26,8 @@ pub enum Error {
     NoLatestBlockRecord,
     #[error("parse block failed")]
     ParseBlockFailed,
-    #[error("can not write data in read-only mode")]
-    ReadOnlyDatabase,
+    #[error("parse block ptr failed")]
+    ParseBlockPtrFailed,
     #[error(transparent)]
     AddrParseError(#[from] AddrParseError),
     #[error(transparent)]
@@ -40,20 +42,19 @@ pub enum Error {
     ParseInt(#[from] ParseIntError),
     #[error(transparent)]
     Reqwest(#[from] reqwest::Error),
-    #[cfg(feature = "full")]
-    #[error(transparent)]
-    RocksDB(#[from] rocksdb::Error),
     #[error(transparent)]
     SerdeJson(#[from] serde_json::Error),
-    #[cfg(feature = "full")]
+    #[cfg(feature = "stream")]
     #[error(transparent)]
     Status(#[from] tonic::Status),
     #[error(transparent)]
     Timestamp(#[from] prost_types::TimestampOutOfSystemRangeError),
-    #[cfg(feature = "full")]
+    #[cfg(feature = "stream")]
     #[error(transparent)]
     Transparent(#[from] tonic::transport::Error),
     #[error(transparent)]
+    Uint(#[from] uint::FromDecStrErr),
+    #[error(transparent)]
     Var(#[from] VarError),
 }
 
